@@ -157,7 +157,16 @@ TSRM_API void tsrm_shutdown(void)
 				int j;
 
 				next_p = p->next;
-				for (j=0; j<id_count; j++) {
+				for (j=0; j<p->count; j++) {
+				/* Disabled - calling dtors in tsrm_shutdown makes
+					modules registering TSRM ids to crash, if they have
+					dtors, since the module is unloaded before tsrm_shutdown 
+					is called. Can be re-enabled after tsrm_free_id is 
+					implemented.
+					if (resource_types_table && resource_types_table[j].dtor) {
+						resource_types_table[j].dtor(p->storage[j], &p->storage);
+					}
+				*/
 					free(p->storage[j]);
 				}
 				free(p->storage);
@@ -276,11 +285,11 @@ static void allocate_new_resource(tsrm_tls_entry **thread_resources_ptr, THREAD_
 		}
 	}
 
-	tsrm_mutex_unlock(tsmm_mutex);
-
 	if (tsrm_new_thread_end_handler) {
 		tsrm_new_thread_end_handler(thread_id, &((*thread_resources_ptr)->storage));
 	}
+
+	tsrm_mutex_unlock(tsmm_mutex);
 }
 
 
@@ -482,6 +491,7 @@ TSRM_API void tsrm_mutex_free(MUTEX_T mutexp)
 	if (mutexp) {
 #ifdef TSRM_WIN32
 		DeleteCriticalSection(mutexp);
+		free(mutexp);
 #elif defined(NETWARE)
 		NXMutexFree(mutexp);
 #elif defined(GNUPTH)
