@@ -67,7 +67,7 @@ static long mem_block_end_magic = MEM_BLOCK_END_MAGIC;
 #define _CHECK_MEMORY_LIMIT(s, rs, file, lineno) { AG(allocated_memory) += rs;\
 								if (AG(memory_limit)<AG(allocated_memory)) {\
 									int php_mem_limit = AG(memory_limit); \
-									if (AG(memory_limit)+1048576 > AG(allocated_memory) - rs) { \
+									if (EG(in_execution) && AG(memory_limit)+1048576 > AG(allocated_memory) - rs) { \
 										AG(memory_limit) = AG(allocated_memory) + 1048576; \
 										if (file) { \
 											zend_error(E_ERROR,"Allowed memory size of %d bytes exhausted at %s:%d (tried to allocate %d bytes)", php_mem_limit, file, lineno, s); \
@@ -482,7 +482,7 @@ ZEND_API void shutdown_memory_manager(int silent, int clean_cache TSRMLS_DC)
 		unsigned int i, j;
 		zend_mem_header *ptr;
 
-		for (i=1; i<MAX_CACHED_MEMORY; i++) {
+		for (i=0; i<MAX_CACHED_MEMORY; i++) {
 			for (j=0; j<AG(cache_count)[i]; j++) {
 				ptr = (zend_mem_header *) AG(cache)[i][j];
 #if MEMORY_LIMIT
