@@ -203,7 +203,7 @@ ZEND_FUNCTION(func_get_arg)
 	arg_count = (ulong) *p;
 
 	if (requested_offset>=arg_count) {
-		zend_error(E_WARNING, "func_get_arg():  Argument %d not passed to function", requested_offset);
+		zend_error(E_WARNING, "func_get_arg():  Argument %ld not passed to function", requested_offset);
 		RETURN_FALSE;
 	}
 
@@ -416,7 +416,7 @@ ZEND_FUNCTION(error_reporting)
 /* }}} */
 
 
-/* {{{ proto bool define(string constant_name, mixed value, case_sensitive=true)
+/* {{{ proto bool define(string constant_name, mixed value, boolean case_sensitive=true)
    Define a new constant */
 ZEND_FUNCTION(define)
 {
@@ -490,9 +490,9 @@ ZEND_FUNCTION(defined)
 	convert_to_string_ex(var);
 	if (zend_get_constant((*var)->value.str.val, (*var)->value.str.len, &c TSRMLS_CC)) {
 		zval_dtor(&c);
-		RETURN_LONG(1);
+		RETURN_TRUE;
 	} else {
-		RETURN_LONG(0);
+		RETURN_FALSE;
 	}
 }
 /* }}} */
