@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2002 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) 1998-2003 Zend Technologies Ltd. (http://www.zend.com) |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        | 
@@ -47,8 +47,10 @@ typedef unsigned int uint;
 #define HAVE_VSNPRINTF	1
 
 #define snprintf _snprintf
+#define strcasecmp(s1, s2) stricmp(s1, s2)
+#define strncasecmp(s1, s2, n) strnicmp(s1, s2, n)
 #define vsnprintf _vsnprintf
-#define zend_isinf(a)	0
+#define zend_isinf(a)	((_fpclass(a) == _FPCLASS_PINF) || (_fpclass(a) == _FPCLASS_NINF))
 #define zend_finite(x)	_finite(x)
 #define zend_isnan(x)	_isnan(x)
 
@@ -64,9 +66,6 @@ typedef unsigned int uint;
 # define inline
 #endif
 
-#define zend_finite(A) _finite(A)
-#define zend_isnan(A) _isnan(A)
-
 #ifdef LIBZEND_EXPORTS
 #	define ZEND_API __declspec(dllexport)
 #else
