@@ -19,7 +19,7 @@
 
 
 #include "zend.h"
-#include "zend_language_parser.h"
+#include <zend_language_parser.h>
 #include "zend_compile.h"
 #include "zend_highlight.h"
 #include "zend_ptr_stack.h"
@@ -100,7 +100,7 @@ ZEND_API void zend_highlight(zend_syntax_highlighter_ini *syntax_highlighter_ini
 	int token_type;
 	char *last_color = syntax_highlighter_ini->highlight_html;
 	char *next_color;
-	int in_string=0;
+	int in_string=0, post_heredoc = 0;
 
 	zend_printf("<code>");
 	zend_printf("<font color=\"%s\">\n", last_color);
@@ -156,9 +156,14 @@ ZEND_API void zend_highlight(zend_syntax_highlighter_ini *syntax_highlighter_ini
 		switch (token_type) {
 			case T_END_HEREDOC:
 				zend_html_puts(token.value.str.val, token.value.str.len TSRMLS_CC);
+				post_heredoc = 1;
 				break;
 			default:
 				zend_html_puts(LANG_SCNG(yy_text), LANG_SCNG(yy_leng) TSRMLS_CC);
+				if (post_heredoc) {
+					 zend_html_putc('\n');
+					 post_heredoc = 0;
+				}
 				break;
 		}
 
