@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2002 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) 1998-2003 Zend Technologies Ltd. (http://www.zend.com) |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        | 
@@ -24,7 +24,7 @@
 typedef struct _zend_lex_state {
 	YY_BUFFER_STATE buffer_state;
 	int state;
-	FILE *in;
+	zend_file_handle *in;
 	uint lineno;
 	char *filename;
 #ifdef ZEND_MULTIBYTE
