@@ -3,7 +3,7 @@
 #elif defined(NETWARE)
 #include "config.nw.h"
 #else
-#include "php_config.h"
+#include <php_config.h>
 #endif
 
 #include <string.h>
