@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: dbase.c,v 1.60.2.1 2002/12/31 16:34:20 sebastian Exp $ */
+/* $Id: dbase.c,v 1.60.2.4 2005/02/04 14:29:20 derick Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -129,6 +129,11 @@ PHP_FUNCTION(dbase_open)
 	convert_to_string(dbf_name);
 	convert_to_long(options);
 
+	if (Z_LVAL_P(options) == 1) {
+		php_error(E_WARNING, "Cannot open %s in write-only mode", Z_STRVAL_P(dbf_name));
+		RETURN_FALSE;
+	}
+	
 	if (PG(safe_mode) && (!php_checkuid(Z_STRVAL_P(dbf_name), NULL, CHECKUID_CHECK_FILE_AND_DIR))) {
 		RETURN_FALSE;
 	}
@@ -298,7 +303,7 @@ PHP_FUNCTION(dbase_add_record)
 		tmp = **field;
 		zval_copy_ctor(&tmp);
 		convert_to_string(&tmp);
-		sprintf(t_cp, cur_f->db_format, Z_STRVAL(tmp));
+		snprintf(t_cp, cur_f->db_flen+1, cur_f->db_format, Z_STRVAL(tmp));
 		zval_dtor(&tmp); 
 		t_cp += cur_f->db_flen;
 	}
@@ -310,7 +315,7 @@ PHP_FUNCTION(dbase_add_record)
 		RETURN_FALSE;
 	}
 
-        put_dbf_info(dbh);
+	put_dbf_info(dbh);
 	efree(cp);
 
 	RETURN_TRUE;
@@ -369,7 +374,7 @@ PHP_FUNCTION(dbase_replace_record)
 			RETURN_FALSE;
 		}
 		convert_to_string_ex(field);
-		sprintf(t_cp, cur_f->db_format, Z_STRVAL_PP(field)); 
+		snprintf(t_cp, cur_f->db_flen+1, cur_f->db_format, Z_STRVAL_PP(field)); 
 		t_cp += cur_f->db_flen;
 	}
 
@@ -674,7 +679,7 @@ PHP_FUNCTION(dbase_create)
 
 		/* field type */
 		if (zend_hash_index_find(Z_ARRVAL_PP (field), 1, (void **)&value) == FAILURE) {
-			php_error(E_WARNING, "expected field type as sececond element of list in field %d", i);
+			php_error(E_WARNING, "expected field type as second element of list in field %d", i);
 			RETURN_FALSE;
 		}
 		convert_to_string_ex(value);
