@@ -41,12 +41,12 @@ gdImageCreateFromPngSource (gdSourcePtr inSource)
 void
 gdImagePngToSink (gdImagePtr im, gdSinkPtr outSink)
 {
-  fprintf(stderr,"PNG support is not available\n");
+  php_gd_error("PNG support is not available\n");
 }
 gdImagePtr
 gdImageCreateFromPngSource (gdSourcePtr inSource)
 {
-  fprintf(stderr,"PNG support is not available\n");
+  php_gd_error("PNG support is not available\n");
   return NULL;
 }
 #endif /* HAVE_LIBPNG */
