@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | msession 1.0                                                         |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2003 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.02 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -1266,7 +1266,7 @@ PS_OPEN_FUNC(msession)
 {
 	int port;
 	int len = strlen(save_path)+1;
-	char * path = alloca(len);
+	char * path = emalloc(len);
 	char * szport;
 
 	strcpy(path, save_path);
@@ -1285,7 +1285,13 @@ PS_OPEN_FUNC(msession)
 	
 	ELOG( "ps_open_msession");
 	PS_SET_MOD_DATA((void *)1); /* session.c needs a non-zero here! */
-	return PHPMsessionConnect(path, port) ? SUCCESS : FAILURE;
+	if (PHPMsessionConnect(path, port)) {
+		efree(path);
+		return SUCCESS;
+	} else {
+		efree(path);
+		return FAILURE;
+	}
 }
 
 PS_CLOSE_FUNC(msession)
