@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2003 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.02 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
  
-/* $Id: php_msql.c,v 1.49 2002/06/26 08:39:36 derick Exp $ */
+/* $Id: php_msql.c,v 1.49.4.2 2005/02/17 20:13:52 andi Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -960,9 +960,14 @@ static void php_msql_fetch_hash(INTERNAL_FUNCTION_PARAMETERS, int result_type)
 				add_assoc_stringl(return_value, msql_field->name, data, data_len, should_copy);
 			}
 		} else {
-			/*
-			add_get_index_stringl(return_value, i, empty_string, 0, (void **) &pval_ptr, 1);
-			*/
+			/* NULL value. */
+			if (result_type & MSQL_NUM) {
+				add_index_null(return_value, i);
+			}
+
+			if (result_type & MSQL_ASSOC) {
+				add_assoc_null(return_value, msql_field->name);
+			}
 		}
 	}
 }
