@@ -18,7 +18,7 @@
    +----------------------------------------------------------------------+
 */
  
-/* $Id: php_mysql.c,v 1.174.2.25 2004/04/23 17:04:36 iliaa Exp $ */
+/* $Id: php_mysql.c,v 1.174.2.28 2005/02/22 15:00:49 iliaa Exp $ */
 
 /* TODO:
  *
@@ -259,6 +259,9 @@ static void _free_mysql_result(zend_rsrc_list_entry *rsrc TSRMLS_DC)
  */
 static void php_mysql_set_default_link(int id TSRMLS_DC)
 {
+	if (MySG(default_link) != -1) {
+		zend_list_delete(MySG(default_link));
+	}
 	MySG(default_link) = id;
 	zend_list_addref(id);
 }
@@ -590,7 +593,7 @@ static void php_mysql_do_connect(INTERNAL_FUNCTION_PARAMETERS, int persistent)
 				break;
 		}
 		/* disable local infile option for open_basedir */
-		if (PG(open_basedir) && strlen(PG(open_basedir))) {
+		if (PG(open_basedir) && strlen(PG(open_basedir)) && (client_flags & CLIENT_LOCAL_FILES)) {
 			client_flags ^= CLIENT_LOCAL_FILES;
 		}
 
@@ -2210,7 +2213,7 @@ static void php_mysql_field_info(INTERNAL_FUNCTION_PARAMETERS, int entry_type)
 {
 	zval **result, **field;
 	MYSQL_RES *mysql_result;
-	MYSQL_FIELD *mysql_field;
+	MYSQL_FIELD *mysql_field = {0};
 	char buf[512];
 	int  len;
 
