@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: posix.c,v 1.51.2.2 2003/03/07 13:42:17 ddhill Exp $ */
+/* $Id: posix.c,v 1.51.2.3 2005/01/28 01:39:42 tony2001 Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -130,7 +130,7 @@ function_entry posix_functions[] = {
 static PHP_MINFO_FUNCTION(posix)
 {
 	php_info_print_table_start();
-	php_info_print_table_row(2, "Revision", "$Revision: 1.51.2.2 $");
+	php_info_print_table_row(2, "Revision", "$Revision: 1.51.2.3 $");
 	php_info_print_table_end();
 }
 /* }}} */
@@ -178,8 +178,9 @@ PHP_FUNCTION(posix_kill)
 {
 	long pid, sig;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ll", &pid, &sig) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ll", &pid, &sig) == FAILURE) {
+		RETURN_FALSE;
+	}
   
 	if (kill(pid, sig) < 0) {
 		POSIX_G(last_error) = errno;
@@ -196,9 +197,10 @@ PHP_FUNCTION(posix_getpid)
 {
 	pid_t  pid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	pid = getpid();
 	RETURN_LONG(pid);
 }
@@ -210,8 +212,9 @@ PHP_FUNCTION(posix_getppid)
 {
 	pid_t  ppid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	ppid = getppid();
 	RETURN_LONG(ppid);
@@ -224,8 +227,9 @@ PHP_FUNCTION(posix_getuid)
 {
 	uid_t  uid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	uid = getuid();
 	RETURN_LONG(uid);
@@ -238,8 +242,9 @@ PHP_FUNCTION(posix_getgid)
 {
 	gid_t  gid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	gid = getgid();
 	RETURN_LONG(gid);
@@ -252,8 +257,9 @@ PHP_FUNCTION(posix_geteuid)
 {
 	uid_t  uid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	uid = geteuid();
 	RETURN_LONG(uid);
@@ -266,9 +272,10 @@ PHP_FUNCTION(posix_getegid)
 {
 	gid_t  gid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	gid = getegid();
 	RETURN_LONG(gid);
  }
@@ -280,9 +287,10 @@ PHP_FUNCTION(posix_setuid)
 {
 	long uid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &uid) == FAILURE)
-		return;
-  
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &uid) == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	if (setuid(uid) < 0) {
 		POSIX_G(last_error) = errno;
 		RETURN_FALSE;
@@ -298,9 +306,10 @@ PHP_FUNCTION(posix_setgid)
 {
 	long gid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &gid) == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &gid) == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	if (setgid(gid) < 0) {
 		POSIX_G(last_error) = errno;
 		RETURN_FALSE;
@@ -317,9 +326,10 @@ PHP_FUNCTION(posix_seteuid)
 {
 	long euid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &euid) == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &euid) == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	if (seteuid(euid) < 0) {
 		POSIX_G(last_error) = errno;
 		RETURN_FALSE;
@@ -337,8 +347,9 @@ PHP_FUNCTION(posix_setegid)
 {
 	long egid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &egid) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &egid) == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	if (setegid(egid) < 0) {
 		POSIX_G(last_error) = errno;
@@ -358,9 +369,10 @@ PHP_FUNCTION(posix_getgroups)
 	int    result;
 	int    i;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
-	
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
+
 	if ((result = getgroups(NGROUPS_MAX, gidlist)) < 0) {
 		POSIX_G(last_error) = errno;
 		RETURN_FALSE;
@@ -385,8 +397,9 @@ PHP_FUNCTION(posix_getlogin)
 {
 	char *p;
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 	
 	if (NULL == (p = getlogin())) {
 		POSIX_G(last_error) = errno;
@@ -403,8 +416,9 @@ PHP_FUNCTION(posix_getpgrp)
 {
 	pid_t  pgrp;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	pgrp = getpgrp();
 	RETURN_LONG(pgrp);
@@ -418,9 +432,10 @@ PHP_FUNCTION(posix_setsid)
 {
 	pid_t  sid;
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	sid = setsid();
 	RETURN_LONG(sid);
 }
@@ -433,8 +448,9 @@ PHP_FUNCTION(posix_setpgid)
 {
 	long pid, pgid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ll", &pid, &pgid) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "ll", &pid, &pgid) == FAILURE) {
+		RETURN_FALSE;
+	}
 	
 	if (setpgid(pid, pgid) < 0) {
 		POSIX_G(last_error) = errno;
@@ -453,8 +469,9 @@ PHP_FUNCTION(posix_getpgid)
 	long pid;
 	pid_t pgid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &pid) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &pid) == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	if ((pgid = getpgid(pid)) < 0) {
 		POSIX_G(last_error) = errno;
@@ -474,8 +491,9 @@ PHP_FUNCTION(posix_getsid)
 	long pid;
 	pid_t sid;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &pid) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &pid) == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	if ((sid = getsid(pid)) < 0) {
 		POSIX_G(last_error) = errno;
@@ -493,8 +511,9 @@ PHP_FUNCTION(posix_uname)
 {
 	struct utsname u;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	if (uname(&u) < 0) {
 		POSIX_G(last_error) = errno;
@@ -530,8 +549,9 @@ PHP_FUNCTION(posix_times)
 	struct tms t;
 	clock_t    ticks;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	if((ticks = times(&t)) < 0) {
 		POSIX_G(last_error) = errno;
@@ -564,9 +584,10 @@ PHP_FUNCTION(posix_ctermid)
 {
 	char  buffer[L_ctermid];
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	if (NULL == ctermid(buffer)) {
 		/* Found no documentation how the defined behaviour is when this
 		 * function fails
@@ -609,9 +630,10 @@ PHP_FUNCTION(posix_ttyname)
 	char *p;
 	int fd;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &z_fd) == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &z_fd) == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	switch (Z_TYPE_P(z_fd)) {
 		case IS_RESOURCE:
 			if (!php_posix_stream_get_fd(z_fd, &fd TSRMLS_CC)) {
@@ -639,8 +661,9 @@ PHP_FUNCTION(posix_isatty)
 	zval *z_fd;
 	int fd;
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &z_fd) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "z", &z_fd) == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	switch (Z_TYPE_P(z_fd)) {
 		case IS_RESOURCE:
@@ -677,8 +700,9 @@ PHP_FUNCTION(posix_getcwd)
 	char  buffer[MAXPATHLEN];
 	char *p;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	p = VCWD_GETCWD(buffer, MAXPATHLEN);
 	if (!p) {
@@ -706,8 +730,9 @@ PHP_FUNCTION(posix_mkfifo)
 	long mode;
 	int     result;
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sl", &path, &path_len, &mode) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "sl", &path, &path_len, &mode) == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	if (PG(safe_mode) && (!php_checkuid(path, NULL, CHECKUID_ALLOW_ONLY_DIR))) {
 		RETURN_FALSE;
@@ -772,8 +797,9 @@ PHP_FUNCTION(posix_getgrnam)
 	struct group *g;
 	int name_len;
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &name, &name_len) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &name, &name_len) == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	if (NULL == (g = getgrnam(name))) {
 		POSIX_G(last_error) = errno;
@@ -802,9 +828,10 @@ PHP_FUNCTION(posix_getgrgid)
 	long gid;
 	struct group *g;
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &gid) == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &gid) == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	if (NULL == (g = getgrgid(gid))) {
 		POSIX_G(last_error) = errno;
 		RETURN_FALSE;
@@ -849,8 +876,9 @@ PHP_FUNCTION(posix_getpwnam)
 	char *name;
 	int name_len;
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &name, &name_len) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "s", &name, &name_len) == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	if (NULL == (pw = getpwnam(name))) {
 		POSIX_G(last_error) = errno;
@@ -877,9 +905,10 @@ PHP_FUNCTION(posix_getpwuid)
 	long uid;
 	struct passwd *pw;
 	
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &uid) == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &uid) == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	if (NULL == (pw = getpwuid(uid))) {
 		POSIX_G(last_error) = errno;
 		RETURN_FALSE;
@@ -1000,9 +1029,10 @@ PHP_FUNCTION(posix_getrlimit)
 {
 	struct limitlist *l = NULL;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
-
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
+	
 	if (array_init(return_value) == FAILURE) {
 		RETURN_FALSE;
 	}
@@ -1020,8 +1050,9 @@ PHP_FUNCTION(posix_getrlimit)
    Retrieve the error number set by the last posix function which failed. */
 PHP_FUNCTION(posix_get_last_error)
 {
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "") == FAILURE) {
+		RETURN_FALSE;
+	}
 	
 	RETURN_LONG(POSIX_G(last_error));
 }
@@ -1033,8 +1064,9 @@ PHP_FUNCTION(posix_strerror)
 {
 	long error;
 
-	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &error) == FAILURE)
-		return;
+	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &error) == FAILURE) {
+		RETURN_FALSE;
+	}
 
 	RETURN_STRING(strerror(error), 1);
 }
