@@ -36,7 +36,7 @@ ZEND_END_MODULE_GLOBALS(extname)
 */
 
 /* In every utility function you add that needs to use variables 
-   in php_extname_globals, call TSRM_FETCH(); after declaring other 
+   in php_extname_globals, call TSRMLS_FETCH(); after declaring other 
    variables used by that function, or better yet, pass in TSRMLS_CC
    after the last function argument and declare your utility function
    with TSRMLS_DC after the last declared argument.  Always refer to
