@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: filestat.c,v 1.112.2.9 2003/09/02 01:23:21 sniper Exp $ */
+/* $Id: filestat.c,v 1.112.2.11 2004/09/02 09:38:56 stas Exp $ */
 
 #include "php.h"
 #include "safe_mode.h"
@@ -128,6 +128,7 @@ PHP_RSHUTDOWN_FUNCTION(filestat)
 {
 	if (BG(CurrentStatFile)) {
 		efree (BG(CurrentStatFile));
+		BG(CurrentStatFile) = NULL;
 	}
 	return SUCCESS;
 }
@@ -613,8 +614,11 @@ static void php_stat(const char *filename, php_stat_len filename_length, int typ
 			if (!IS_LINK_OPERATION(type) && (!IS_EXISTS_CHECK(type) || (errno != ENOENT && errno != ENOTDIR))) { /* fileexists() test must print no error */
 				php_error_docref(NULL TSRMLS_CC, E_WARNING, "Stat failed for %s (errno=%d - %s)", BG(CurrentStatFile), errno, strerror(errno));
 			}
-			efree(BG(CurrentStatFile));
-			BG(CurrentStatFile) = NULL;
+			/* This could be null if a failed stat leads to a user error handler which calls a failed stat */
+			if (BG(CurrentStatFile)) {
+				efree(BG(CurrentStatFile));
+				BG(CurrentStatFile) = NULL;
+			}
 #if HAVE_SYMLINK
 			if (!IS_LINK_OPERATION(type))  /* Don't require success for link operation */
 #endif
