@@ -17,7 +17,7 @@
  */
 
 
-/* $Id: incomplete_class.c,v 1.14.4.4 2004/09/24 21:57:18 helly Exp $ */
+/* $Id: incomplete_class.c,v 1.14.4.5 2005/03/03 10:41:19 johannes Exp $ */
 
 #include "php.h"
 #include "basic_functions.h"
@@ -26,7 +26,7 @@
 #define INCOMPLETE_CLASS_MSG \
 		"The script tried to execute a method or "  \
 		"access a property of an incomplete object. " \
-		"Please ensure that the class definition <b>%s</b> of the object " \
+		"Please ensure that the class definition %s of the object " \
 		"you are trying to operate on was loaded _before_ " \
 		"the session was started"
 
