@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: type.c,v 1.20.4.1 2002/12/31 16:35:35 sebastian Exp $ */
+/* $Id: type.c,v 1.20.4.2 2004/04/01 08:56:32 derick Exp $ */
 
 #include "php.h"
 #include "php_incomplete_class.h"
@@ -208,6 +208,13 @@ static void php_is_type(INTERNAL_FUNCTION_PARAMETERS, int type)
 				RETURN_FALSE;
 			}
 		}
+		if (type == IS_RESOURCE) {
+			char *type_name;
+			type_name = zend_rsrc_list_get_rsrc_type(Z_LVAL_PP(arg) TSRMLS_CC);
+			if (!type_name) {
+				RETURN_FALSE;
+			}
+		}
 		RETURN_TRUE;
 	} else {
 		RETURN_FALSE;
