@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: tokenizer.c,v 1.12.2.2 2003/07/24 02:53:45 sniper Exp $ */
+/* $Id: tokenizer.c,v 1.12.2.4 2003/11/29 19:05:58 iliaa Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -346,7 +346,12 @@ static void tokenize(zval *return_value TSRMLS_DC)
 			MAKE_STD_ZVAL(keyword);
 			array_init(keyword);
 			add_next_index_long(keyword, token_type);
-			add_next_index_stringl(keyword, zendtext, zendleng, 1);
+			if (token_type == T_END_HEREDOC) {
+				add_next_index_stringl(keyword, Z_STRVAL(token), Z_STRLEN(token), 1);
+				efree(Z_STRVAL(token));
+			} else {
+				add_next_index_stringl(keyword, zendtext, zendleng, 1);
+			}
 			add_next_index_zval(return_value, keyword);
 		} else {
 			add_next_index_stringl(return_value, zendtext, zendleng, 1);
