@@ -36,6 +36,9 @@
  *   Dan Libby, aka danda  (dan@libby.com)
  * HISTORY
  *   $Log: xmlrpc_introspection.c,v $
+ *   Revision 1.3.4.1  2003/12/16 21:00:36  sniper
+ *   MFH: fix compile warnings
+ *
  *   Revision 1.3  2002/07/05 04:43:53  danda
  *   merged in updates from SF project.  bring php repository up to date with xmlrpc-epi version 0.51
  *
@@ -346,7 +349,7 @@ XMLRPC_VALUE xml_element_to_method_description(xml_element* el, XMLRPC_ERROR err
          const char* ptype = !strcmp(el->name, "value") ? type : basetype;
          if(ptype) {
             if(Q_Size(&el->children) &&
-               !strcmp(ptype, "array") || !strcmp(ptype, "struct") || !strcmp(ptype, "mixed")) {
+               (!strcmp(ptype, "array") || !strcmp(ptype, "struct") || !strcmp(ptype, "mixed"))) {
                xSubList = XMLRPC_CreateVector("member", xmlrpc_vector_array);
 
                if(xSubList) {
