@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php_sprintf.c,v 1.12.8.4 2004/11/15 23:27:26 fmk Exp $ */
+/* $Id: php_sprintf.c,v 1.12.8.5 2004/12/17 13:07:57 derick Exp $ */
 
 #include <stdio.h>
 #include <stdarg.h>
@@ -26,7 +26,7 @@ PHPAPI int
 php_sprintf (char*s, const char* format, ...)
 {
   va_list args;
-  char *ret;
+  int ret;
 
   va_start (args, format);
   s[0] = '\0';
