@@ -16,7 +16,7 @@
   +----------------------------------------------------------------------+
 */
 
-/* $Id: snprintf.c,v 1.17.4.9 2003/09/29 23:44:17 iliaa Exp $ */
+/* $Id: snprintf.c,v 1.17.4.11 2004/11/15 23:27:26 fmk Exp $ */
 
 /* ====================================================================
  * Copyright (c) 1995-1998 The Apache Group.  All rights reserved.
@@ -462,8 +462,6 @@ ap_php_gcvt(double number, int ndigit, char *buf, boolean_e altform)
 	return (buf);
 }
 
-#if !defined(HAVE_SNPRINTF) || !defined(HAVE_VSNPRINTF) || PHP_BROKEN_SNPRINTF || PHP_BROKEN_VSNPRINTF
-
 /*
  * NUM_BUF_SIZE is the size of the buffer used for arithmetic conversions
  *
@@ -968,7 +966,7 @@ static void strx_printv(int *ccp, char *buf, size_t len, const char *format,
 }
 
 
-int ap_php_snprintf(char *buf, size_t len, const char *format,...)
+PHPAPI int ap_php_snprintf(char *buf, size_t len, const char *format,...)
 {
 	int cc;
 	va_list ap;
@@ -980,7 +978,7 @@ int ap_php_snprintf(char *buf, size_t len, const char *format,...)
 }
 
 
-int ap_php_vsnprintf(char *buf, size_t len, const char *format, va_list ap)
+PHPAPI int ap_php_vsnprintf(char *buf, size_t len, const char *format, va_list ap)
 {
 	int cc;
 
@@ -988,8 +986,6 @@ int ap_php_vsnprintf(char *buf, size_t len, const char *format, va_list ap)
 	return (cc);
 }
 
-#endif							/* HAVE_SNPRINTF */
-
 /*
  * Local variables:
  * tab-width: 4
