@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: php_functions.c,v 1.1.2.10 2003/11/11 20:04:19 iliaa Exp $ */
+/* $Id: php_functions.c,v 1.1.2.12 2005/01/24 11:48:35 jorton Exp $ */
 
 #include "php.h"
 #include "ext/standard/php_smart_str.h"
@@ -63,6 +63,7 @@ static request_rec *php_apache_lookup_uri(char *filename TSRMLS_DC)
 	}
 	
 	ctx = SG(server_context);
+
 	return ap_sub_req_lookup_uri(filename, ctx->r, ctx->r->output_filters);
 }
 
@@ -95,6 +96,10 @@ PHP_FUNCTION(virtual)
 	php_end_ob_buffers(1 TSRMLS_CC);
 	php_header();
 
+	/* Ensure that the ap_r* layer for the main request is flushed, to
+	 * work around http://issues.apache.org/bugzilla/show_bug.cgi?id=17629 */
+	ap_rflush(rr->main);
+
 	if (ap_run_sub_req(rr)) {
 		php_error_docref(NULL TSRMLS_CC, E_WARNING, "Unable to include '%s' - request execution failed", Z_STRVAL_PP(filename));
 		ap_destroy_sub_req(rr);
