@@ -214,7 +214,10 @@ static int sapi_cli_ub_write(const char *str, uint str_length TSRMLS_DC)
 
 static void sapi_cli_flush(void *server_context)
 {
-	if (fflush(stdout)==EOF) {
+	/* Ignore EBADF here, it's caused by the fact that STDIN/STDOUT/STDERR streams
+	 * are/could be closed before fflush() is called.
+	 */
+	if (fflush(stdout)==EOF && errno!=EBADF) {
 		php_handle_aborted_connection();
 	}
 }
@@ -436,20 +439,23 @@ static void cli_register_file_handles(TSRMLS_D)
 	
 	ic.value = *zin;
 	ic.flags = CONST_CS;
-	ic.name = zend_strndup("STDIN", 6);
-	ic.name_len = 6;
+	ic.name = zend_strndup(ZEND_STRL("STDIN"));
+	ic.name_len = sizeof("STDIN");
+	ic.module_number = 0;
 	zend_register_constant(&ic TSRMLS_CC);
 
 	oc.value = *zout;
 	oc.flags = CONST_CS;
-	oc.name = zend_strndup("STDOUT", 7);
-	oc.name_len = 7;
+	oc.name = zend_strndup(ZEND_STRL("STDOUT"));
+	oc.name_len = sizeof("STDOUT");
+	oc.module_number = 0;
 	zend_register_constant(&oc TSRMLS_CC);
 
 	ec.value = *zerr;
 	ec.flags = CONST_CS;
-	ec.name = zend_strndup("STDERR", 7);
-	ec.name_len = 7;
+	ec.name = zend_strndup(ZEND_STRL("STDERR"));
+	ec.name_len = sizeof("STDERR");
+	ec.module_number = 0;
 	zend_register_constant(&ec TSRMLS_CC);
 
 	FREE_ZVAL(zin);
