@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2003 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.02 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: thttpd.c,v 1.77 2002/11/08 13:29:32 sas Exp $ */
+/* $Id: thttpd.c,v 1.77.2.15 2003/07/01 05:28:53 sas Exp $ */
 
 #include "php.h"
 #include "SAPI.h"
@@ -42,14 +42,19 @@
 
 typedef struct {
 	httpd_conn *hc;
-	int read_post_data;	
 	void (*on_close)(int);
 
+	size_t unconsumed_length;
 	smart_str sbuf;
 	int seen_cl;
 	int seen_cn;
 } php_thttpd_globals;
 
+#define PHP_SYS_CALL(x) do { x } while (n == -1 && errno == EINTR)
+
+#ifdef PREMIUM_THTTPD
+# define do_keep_alive persistent
+#endif
 
 #ifdef ZTS
 static int thttpd_globals_id;
@@ -70,7 +75,7 @@ static int sapi_thttpd_ub_write(const char *str, uint str_length TSRMLS_DC)
 	}
 	
 	while (str_length > 0) {
-		n = send(TG(hc)->conn_fd, str, str_length, 0);
+		PHP_SYS_CALL(n = send(TG(hc)->conn_fd, str, str_length, 0););
 
 		if (n == -1) {
 			if (errno == EAGAIN) {
@@ -90,23 +95,22 @@ static int sapi_thttpd_ub_write(const char *str, uint str_length TSRMLS_DC)
 	return sent;
 }
 
-#define ADD_VEC(str,l) vec[n].iov_base=str;len += (vec[n].iov_len=l); n++
-#define COMBINE_HEADERS 30
+#define COMBINE_HEADERS 64
+
+#if defined(IOV_MAX)
+# if IOV_MAX - 64 <= 0
+#  define SERIALIZE_HEADERS
+# endif
+#endif
 
 static int do_writev(struct iovec *vec, int nvec, int len TSRMLS_DC)
 {
 	int n;
 
-	/*
-	 * XXX: partial writevs are not handled
-	 * This can only cause problems, if the user tries to send
-	 * huge headers, so I consider this a void issue right now.
-	 * The maximum size depends on SO_SNDBUF and is usually
-	 * at least 16KB from my experience.
-	 */
-	
+	assert(nvec <= IOV_MAX);
+
 	if (TG(sbuf).c == 0) {
-		n = writev(TG(hc)->conn_fd, vec, nvec);
+		PHP_SYS_CALL(n = writev(TG(hc)->conn_fd, vec, nvec););
 
 		if (n == -1) {
 			if (errno == EAGAIN) {
@@ -118,8 +122,9 @@ static int do_writev(struct iovec *vec, int nvec, int len TSRMLS_DC)
 
 
 		TG(hc)->bytes_sent += n;
-	} else
+	} else {
 		n = 0;
+	}
 
 	if (n < len) {
 		int i;
@@ -147,6 +152,18 @@ static int do_writev(struct iovec *vec, int nvec, int len TSRMLS_DC)
 	return 0;
 }
 
+#ifdef SERIALIZE_HEADERS
+# define ADD_VEC(str,l) smart_str_appendl(&vec_str, (str), (l))
+# define VEC_BASE() smart_str vec_str = {0}
+# define VEC_FREE() smart_str_free(&vec_str)
+#else
+# define ADD_VEC(str,l) vec[n].iov_base=str;len += (vec[n].iov_len=l); n++
+# define VEC_BASE() struct iovec vec[COMBINE_HEADERS]
+# define VEC_FREE() do {} while (0)
+#endif
+
+#define ADD_VEC_S(str) ADD_VEC((str), sizeof(str)-1)
+
 #define CL_TOKEN "Content-length: "
 #define CN_TOKEN "Connection: "
 #define KA_DO "Connection: keep-alive\r\n"
@@ -155,17 +172,19 @@ static int do_writev(struct iovec *vec, int nvec, int len TSRMLS_DC)
 
 static int sapi_thttpd_send_headers(sapi_headers_struct *sapi_headers TSRMLS_DC)
 {
-	char buf[1024];
-	struct iovec vec[COMBINE_HEADERS];
+	char buf[1024], *p;
+	VEC_BASE();
 	int n = 0;
 	zend_llist_position pos;
 	sapi_header_struct *h;
 	size_t len = 0;
 	
 	if (!SG(sapi_headers).http_status_line) {
-		sprintf(buf, "HTTP/1.1 %d Code\r\n",  /* SAFE */
+		ADD_VEC_S("HTTP/1.1 ");
+		p = smart_str_print_long(buf+sizeof(buf)-1, 
 				SG(sapi_headers).http_response_code);
-		ADD_VEC(buf, strlen(buf));
+		ADD_VEC(p, strlen(p));
+		ADD_VEC_S(" HTTP\r\n");
 	} else {
 		ADD_VEC(SG(sapi_headers).http_status_line, 
 				strlen(SG(sapi_headers).http_status_line));
@@ -190,10 +209,12 @@ static int sapi_thttpd_send_headers(sapi_headers_struct *sapi_headers TSRMLS_DC)
 		}
 
 		ADD_VEC(h->header, h->header_len);
+#ifndef SERIALIZE_HEADERS
 		if (n >= COMBINE_HEADERS - 1) {
 			len = do_writev(vec, n, len TSRMLS_CC);
 			n = 0;
 		}
+#endif
 		ADD_VEC("\r\n", 2);
 		
 		h = zend_llist_get_next_ex(&sapi_headers->headers, &pos);
@@ -202,12 +223,19 @@ static int sapi_thttpd_send_headers(sapi_headers_struct *sapi_headers TSRMLS_DC)
 	if (TG(seen_cl) && !TG(seen_cn) && TG(hc)->do_keep_alive) {
 		ADD_VEC(KA_DO, sizeof(KA_DO)-1);
 	} else {
+		TG(hc)->do_keep_alive = 0;
 		ADD_VEC(KA_NO, sizeof(KA_NO)-1);
 	}
 		
 	ADD_VEC("\r\n", 2);
-			
+
+#ifdef SERIALIZE_HEADERS
+	sapi_thttpd_ub_write(vec_str.c, vec_str.len TSRMLS_CC);
+#else			
 	do_writev(vec, n, len TSRMLS_CC);
+#endif
+
+	VEC_FREE();
 
 	return SAPI_HEADER_SENT_SUCCESSFULLY;
 }
@@ -219,51 +247,13 @@ static int sapi_thttpd_send_headers(sapi_headers_struct *sapi_headers TSRMLS_DC)
 
 static int sapi_thttpd_read_post(char *buffer, uint count_bytes TSRMLS_DC)
 {
-	size_t read_bytes = 0, tmp;
-	int c;
-	int n;
+	size_t read_bytes = 0;
 
-	c = SIZEOF_UNCONSUMED_BYTES();
-	if (c > 0) {
-		read_bytes = MIN(c, count_bytes);
+	if (TG(unconsumed_length) > 0) {
+		read_bytes = MIN(TG(unconsumed_length), count_bytes);
 		memcpy(buffer, TG(hc)->read_buf + TG(hc)->checked_idx, read_bytes);
+		TG(unconsumed_length) -= read_bytes;
 		CONSUME_BYTES(read_bytes);
-		count_bytes -= read_bytes;
-	}
-	
-	count_bytes = MIN(count_bytes, 
-			SG(request_info).content_length - SG(read_post_bytes));
-
-	while (read_bytes < count_bytes) {
-		tmp = recv(TG(hc)->conn_fd, buffer + read_bytes, 
-				count_bytes - read_bytes, 0);
-		if (tmp == 0 || (tmp == -1 && errno != EAGAIN))
-			break;
-		/* A simple "tmp > 0" produced broken code on Solaris/GCC */
-		if (tmp != 0 && tmp != -1)
-			read_bytes += tmp;
-
-		if (tmp == -1 && errno == EAGAIN) {
-			fd_set fdr;
-
-			FD_ZERO(&fdr);
-			FD_SET(TG(hc)->conn_fd, &fdr);
-			n = select(TG(hc)->conn_fd + 1, &fdr, NULL, NULL, NULL);
-			if (n <= 0)
-				php_handle_aborted_connection();
-
-			continue;
-		}
-	}
-
-	TG(read_post_data) += read_bytes;
-
-	/* Hack for user-agents which send a LR or CRLF after POST data */
-	if (TG(read_post_data) >= TG(hc)->contentlength) {
-		char tmpbuf[2];
-	
-		/* we are in non-blocking mode */
-		recv(TG(hc)->conn_fd, tmpbuf, 2, 0);
 	}
 	
 	return read_bytes;
@@ -275,14 +265,14 @@ static char *sapi_thttpd_read_cookies(TSRMLS_D)
 }
 
 #define BUF_SIZE 512
-#define ADD_STRING(name)										\
+#define ADD_STRING_EX(name,buf)									\
 	php_register_variable(name, buf, track_vars_array TSRMLS_CC)
+#define ADD_STRING(name) ADD_STRING_EX((name), buf)
 
 static void sapi_thttpd_register_variables(zval *track_vars_array TSRMLS_DC)
 {
 	char buf[BUF_SIZE + 1];
 	char *p;
-	int xsa_len;
 
 	php_register_variable("PHP_SELF", SG(request_info).request_uri, track_vars_array TSRMLS_CC);
 	php_register_variable("SERVER_SOFTWARE", SERVER_SOFTWARE, track_vars_array TSRMLS_CC);
@@ -297,32 +287,21 @@ static void sapi_thttpd_register_variables(zval *track_vars_array TSRMLS_DC)
 		php_register_variable("SERVER_PROTOCOL", "HTTP/1.0", track_vars_array TSRMLS_CC);
 	}
 
-#ifdef HAVE_GETNAMEINFO
-	switch (TG(hc)->client_addr.sa.sa_family) {
-		case AF_INET: xsa_len = sizeof(struct sockaddr_in); break;
-		case AF_INET6: xsa_len = sizeof(struct sockaddr_in6); break;
-		default: xsa_len = 0;
-	}
+	p = httpd_ntoa(&TG(hc)->client_addr);	
+	
+	ADD_STRING_EX("REMOTE_ADDR", p);
+	ADD_STRING_EX("REMOTE_HOST", p);
 
-	if (getnameinfo(&TG(hc)->client_addr.sa, xsa_len, buf, sizeof(buf), 0, 0, NI_NUMERICHOST) == 0) {
-#else
-	p = inet_ntoa(TG(hc)->client_addr.sa_in.sin_addr);
-		
-	/* string representation of IPs are never larger than 512 bytes */
-	if (p) {
-		memcpy(buf, p, strlen(p) + 1);
-#endif
-		ADD_STRING("REMOTE_ADDR");
-		ADD_STRING("REMOTE_HOST");
-	}
+	ADD_STRING_EX("SERVER_PORT",
+			smart_str_print_long(buf + sizeof(buf) - 1,
+				TG(hc)->hs->port));
 
-	snprintf(buf, BUF_SIZE, "%d", TG(hc)->hs->port);
-	ADD_STRING("SERVER_PORT");
-
-	snprintf(buf, BUF_SIZE, "/%s", TG(hc)->pathinfo);
+	buf[0] = '/';
+	memcpy(buf + 1, TG(hc)->pathinfo, strlen(TG(hc)->pathinfo) + 1);
 	ADD_STRING("PATH_INFO");
 
-	snprintf(buf, BUF_SIZE, "/%s", TG(hc)->origfilename);
+	buf[0] = '/';
+	memcpy(buf + 1, TG(hc)->origfilename, strlen(TG(hc)->origfilename) + 1);
 	ADD_STRING("SCRIPT_NAME");
 
 #define CONDADD(name, field) 							\
@@ -343,8 +322,9 @@ static void sapi_thttpd_register_variables(zval *track_vars_array TSRMLS_DC)
 	CONDADD(SERVER_PROTOCOL, protocol);
 
 	if (TG(hc)->contentlength != -1) {
-		sprintf(buf, "%ld", (long) TG(hc)->contentlength);
-		ADD_STRING("CONTENT_LENGTH");
+		ADD_STRING_EX("CONTENT_LENGTH",
+				smart_str_print_long(buf + sizeof(buf) - 1, 
+					TG(hc)->contentlength));
 	}
 
 	if (TG(hc)->authorization[0])
@@ -382,6 +362,12 @@ static int php_thttpd_startup(sapi_module_struct *sapi_module)
 	return SUCCESS;
 }
 
+static int sapi_thttpd_get_fd(int *nfd TSRMLS_DC)
+{
+	if (nfd) *nfd = TG(hc)->conn_fd;
+	return SUCCESS;
+}
+
 static sapi_module_struct thttpd_sapi_module = {
 	"thttpd",
 	"thttpd",
@@ -408,15 +394,20 @@ static sapi_module_struct thttpd_sapi_module = {
 	sapi_thttpd_register_variables,
 	NULL,									/* Log message */
 
+	NULL,									/* php.ini path override */
 	NULL,									/* Block interruptions */
 	NULL,									/* Unblock interruptions */
 
-	STANDARD_SAPI_MODULE_PROPERTIES
+	NULL,
+	NULL,
+	NULL,
+	0,
+	sapi_thttpd_get_fd
 };
 
 static void thttpd_module_main(int show_source TSRMLS_DC)
 {
-	zend_file_handle file_handle;
+	zend_file_handle file_handle = {0};
 
 	if (php_request_startup(TSRMLS_C) == FAILURE) {
 		return;
@@ -460,9 +451,12 @@ static void thttpd_request_ctor(TSRMLS_D)
 	SG(request_info).request_uri = s.c;
 	SG(request_info).request_method = httpd_method_str(TG(hc)->method);
 	SG(sapi_headers).http_response_code = 200;
-	SG(request_info).content_type = TG(hc)->contenttype;
+	if (TG(hc)->contenttype)
+		SG(request_info).content_type = strdup(TG(hc)->contenttype);
 	SG(request_info).content_length = TG(hc)->contentlength == -1 ? 0
 		: TG(hc)->contentlength;
+
+	TG(unconsumed_length) = SG(request_info).content_length;
 	
 	php_handle_auth_data(TG(hc)->authorization TSRMLS_CC);
 }
@@ -474,6 +468,8 @@ static void thttpd_request_dtor(TSRMLS_D)
 		free(SG(request_info).query_string);
 	free(SG(request_info).request_uri);
 	free(SG(request_info).path_translated);
+	if (SG(request_info).content_type)
+		free(SG(request_info).content_type);
 }
 
 #ifdef ZTS
@@ -653,27 +649,20 @@ static void remove_dead_conn(int fd)
 
 #endif
 
-#define CT_LEN_MAX_RAM 8192
-
 static off_t thttpd_real_php_request(httpd_conn *hc, int show_source TSRMLS_DC)
 {
 	TG(hc) = hc;
 	hc->bytes_sent = 0;
 
-	TG(read_post_data) = 0;
-	if (hc->method == METHOD_POST)
+	if (hc->contentlength != -1) {
 		hc->should_linger = 1;
+		hc->do_keep_alive = 0;
+	}
 	
-	if (hc->contentlength > 0 
+	if (hc->contentlength != -1
 			&& SIZEOF_UNCONSUMED_BYTES() < hc->contentlength) {
-		int missing = hc->contentlength - SIZEOF_UNCONSUMED_BYTES();
-		
-		if (hc->contentlength < CT_LEN_MAX_RAM) {
-			hc->read_body_into_mem = 1;
-			return 0;
-		} else {
-			return -1;
-		}
+		hc->read_body_into_mem = 1;
+		return 0;
 	}
 	
 	thttpd_request_ctor(TSRMLS_C);
@@ -682,7 +671,7 @@ static off_t thttpd_real_php_request(httpd_conn *hc, int show_source TSRMLS_DC)
 
 	/* disable kl, if no content-length was seen or Connection: was set */
 	if (TG(seen_cl) == 0 || TG(seen_cn) == 1) {
-		TG(hc)->do_keep_alive = TG(hc)->keep_alive = 0;
+		TG(hc)->do_keep_alive = 0;
 	}
 	
 	if (TG(sbuf).c != 0) {
@@ -691,6 +680,7 @@ static off_t thttpd_real_php_request(httpd_conn *hc, int show_source TSRMLS_DC)
 		
 		TG(hc)->response = TG(sbuf).c;
 		TG(hc)->responselen = TG(sbuf).len;
+		TG(hc)->maxresponse = TG(sbuf).a;
 
 		TG(sbuf).c = 0;
 		TG(sbuf).len = 0;
@@ -733,7 +723,9 @@ int thttpd_get_fd(void)
 void thttpd_set_dont_close(void)
 {
 	TSRMLS_FETCH();
+#ifndef PREMIUM_THTTPD
 	TG(hc)->file_address = (char *) 1;
+#endif
 }
 
 
