@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | PHP Version 4                                                        |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2002 The PHP Group                                |
+   | Copyright (c) 1997-2003 The PHP Group                                |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.02 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id: crypt_win32.c,v 1.3.2.1 2002/03/23 14:51:30 edink Exp $ */
+/* $Id: crypt_win32.c,v 1.4.4.1 2002/12/31 16:35:50 sebastian Exp $ */
 
 /* This code is distributed under the PHP license with permission from
    the author Jochen Obalek <jochen.obalek@bigfoot.de> */
@@ -41,6 +41,7 @@
 #include <time.h>
 #include <string.h>
 #include <stdlib.h>
+#include "md5crypt.h"
 
 #define BS  64
 #define BS2 32
@@ -271,7 +272,7 @@ setkey (char *schl)
 }
 
 char *
-crypt (const char *wort, const char *salt)
+des_crypt (const char *wort, const char *salt)
 {
   static char retkey[14];
   char key[BS + 2];
@@ -343,4 +344,12 @@ crypt (const char *wort, const char *salt)
   return retkey;
 }
 
-
+char *
+crypt (const char *pw, const char *salt)
+{
+	if (strlen(salt)>MD5_MAGIC_LEN && strncmp(salt, MD5_MAGIC, MD5_MAGIC_LEN)==0) {
+		return md5_crypt(pw, salt);
+	} else {
+		return des_crypt(pw, salt);
+	}
+}
