@@ -17,7 +17,7 @@
  *
  */
 
-/* $Id: sendmail.c,v 1.47.2.8 2003/09/08 22:37:51 iliaa Exp $ */
+/* $Id: sendmail.c,v 1.47.2.10 2005/01/19 18:54:57 iliaa Exp $ */
 
 #include "php.h"				/*php specific */
 #include <stdio.h>
@@ -211,6 +211,7 @@ int TSendMail(char *host, int *error, char **error_message,
 	int ret;
 	char *RPath = NULL;
 	char *headers_lc = NULL; /* headers_lc is only created if we've a header at all */
+	char *pos1 = NULL, *pos2 = NULL;
 	TSRMLS_FETCH();
 
 	WinsockStarted = FALSE;
@@ -250,9 +251,21 @@ int TSendMail(char *host, int *error, char **error_message,
 	/* Fall back to sendmail_from php.ini setting */
 	if (mailRPath && *mailRPath) {
 		RPath = estrdup(mailRPath);
-	}
-	else if (INI_STR("sendmail_from")) {
+	} else if (INI_STR("sendmail_from")) {
 		RPath = estrdup(INI_STR("sendmail_from"));
+	} else if (	headers_lc &&
+				(pos1 = strstr(headers_lc, "from:")) &&
+				((pos1 == headers_lc) || (*(pos1-1) == '\n'))
+	) {
+		/* Real offset is memaddress from the original headers + difference of
+		 * string found in the lowercase headrs + 5 characters to jump over   
+		 * the from: */
+		pos1 = headers + (pos1 - headers_lc) + 5;
+		if (NULL == (pos2 = strstr(pos1, "\r\n"))) {
+			RPath = estrndup(pos1, strlen(pos1));
+		} else {
+			RPath = estrndup(pos1, pos2-pos1);
+		}
 	} else {
 		if (headers) {
 			efree(headers);
@@ -449,7 +462,7 @@ int SendText(char *RPath, char *Subject, char *mailTo, char *mailCc, char *mailB
 		efree(tempMailTo);
 	}
 	/* Send mail to all Cc rcpt's */
-	else if (headers && (pos1 = strstr(headers_lc, "cc:")) && ((pos1 == headers_lc) || iscntrl(*(pos1-1)))) {
+	else if (headers && (pos1 = strstr(headers_lc, "cc:")) && ((pos1 == headers_lc) || (*(pos1-1) == '\n'))) {
 		/* Real offset is memaddress from the original headers + difference of
 		 * string found in the lowercase headrs + 3 characters to jump over
 		 * the cc: */
